#! /usr/bin/perl -w
# $Id: check_graph_tcp.pl,v 1.2 2005/08/01 17:50:50 gollum123 Exp $
#
# This plugin is developped under GPL Licence:
# http://www.fsf.org/licenses/gpl.txt

# Developped by Linagora SA: http://www.linagora.com

# Modified for Oreon Project by : Mathieu Chateau - Christophe Coraboeuf

# The Software is provided to you AS IS and WITH ALL FAULTS.
# LINAGORA makes no representation and gives no warranty whatsoever,
# whether express or implied, and without limitation, with regard to the quality,
# safety, contents, performance, merchantability, non-infringement or suitability for
# any particular or intended purpose of the Software found on the LINAGORA web site.
# In no event will LINAGORA be liable for any direct, indirect, punitive, special,
# incidental or consequential damages however they may arise and even if LINAGORA has
# been previously advised of the possibility of such damages.

# based on "graph plugins" developped by Oreon Team. See http://www.oreon.org.

use strict;
use FindBin;
use lib "$FindBin::Bin";
use lib "@NAGIOS_PLUGINS@";
use utils qw($TIMEOUT %ERRORS &print_revision &support);

if (eval "require oreon" ) {
	use oreon qw(get_parameters create_rrd update_rrd &is_valid_serviceid);
	use vars qw($VERSION %oreon);
	%oreon=get_parameters();
} else {
	print "Unable to load oreon perl module\n";
    exit $ERRORS{'UNKNOWN'};
}

use Getopt::Long;
use vars qw($opt_V $opt_h $opt_p $opt_c $opt_w $opt_H $opt_S $opt_g $opt_D $opt_step $step);
use vars qw($PROGNAME);

my $pathtorrdbase = $oreon{GLOBAL}{DIR_RRDTOOL};
my $pathtolibexectcp = $oreon{GLOBAL}{NAGIOS_LIBEXEC}."check_tcp";

sub print_help ();
sub print_usage ();
$PROGNAME = "check_graph_tcp";

# get options
Getopt::Long::Configure('bundling');
GetOptions
    ("h|help"   		=> \$opt_h,
     "V|version"   		=> \$opt_V,
     "H|hostname=s" 	=> \$opt_H,
     "p|port=s" 		=> \$opt_p,
     "w|warning=s" 		=> \$opt_w,
     "c|critical=s" 	=> \$opt_c,
     "S|ServiceId=s" 	=> \$opt_S,
     "rrd_step=s" => \$opt_step,
     "g|rrdgraph"   	=> \$opt_g);


# help required
if (defined($opt_h)) {
        print_help();
        exit $ERRORS{'OK'};
}

$opt_H = shift unless ($opt_H);
(print_usage() && exit $ERRORS{'OK'}) unless ($opt_H);

($opt_S) || ($opt_S = shift) || ($opt_S = 1);
my $ServiceId = is_valid_serviceid($opt_S);

($opt_step) || ($opt_step = shift) || ($opt_step = "300");
$step = $1 if ($opt_step =~ /(\d+)/);


my $args_check_tcp = "-H $opt_H -p $opt_p";

if ( $opt_w ) {
    $args_check_tcp .= " -w $opt_w";
}

if ( $opt_c ) {
    $args_check_tcp .= " -c $opt_c";
}

my $rrd = $pathtorrdbase.$ServiceId.".rrd";
my $start=time;


##
## RRDTools create rrd
##
if ($opt_g) {
    if (! -e $rrd) {
          	create_rrd ($rrd,1,$start,$step,"U","U","GAUGE");
        }
}


my $result = `$pathtolibexectcp $args_check_tcp`;
my $return_code = $? / 256;
$_ = $result;
m/(\d*\.\d*) second/;
my $time = $1;

#print "time: $time";
##
## RRDtools update
##
if ($opt_g && $time ) {
    $start=time;
    update_rrd ($rrd,$start,$time);
}

print "$result";
exit $return_code;

sub print_usage () {
    print "\nUsage:\n";
    print $0."\n";
    print "   -H (--hostname)   Hostname to query - (required)\n";
    print "   -p, --port=INTEGER Port number - (required)\n";
    print "   -w, --warning=DOUBLE Response time to result in warning status (seconds)\n";
    print "   -c, --critical=DOUBLE Response time to result in critical status (seconds)\n";
    print "   --rrd_step	    Specifies the base interval in seconds with which data will be fed into the RRD (300 by default)\n";
    print "   -V (--version)    Plugin version\n";
    print "   -h (--help)       usage help\n";

}

sub print_help () {
    print "Copyright (c) 2005 LINAGORA SA\n";
    print "Bugs to http://www.linagora.com/\n";
    print "\n";
    print_usage();
    print "\n";
}






